classpath-patches
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[cp-patches] FYI: minor API doc fixes in java.util.*


From: David Gilbert
Subject: [cp-patches] FYI: minor API doc fixes in java.util.*
Date: Tue, 05 Jul 2005 11:28:29 +0000
User-agent: Mozilla Thunderbird 1.0.2 (X11/20050426)

I committed this patch to fix some minor problems in the API docs for
the java.util.* package:

2005-07-05  David Gilbert  <address@hidden>

        * java/util/BitSet.java: fixed minor problems in API docs,
        * java/util/Calendar.java: likewise,
        * java/util/Collections.java: likewise,
        * java/util/Date.java: likewise,
        * java/util/Hashtable.java: likewise,
        * java/util/LinkedList.java: likewise,
        * java/util/Properties.java: likewise,
        * java/util/PropertyResourceBundle.java: likewise,
        * java/util/ResourceBundle.java: likewise,
        * java/util/SimpleTimeZone.java: likewise,
        * java/util/TreeMap.java: likewise.

Regards,

Dave Gilbert

Index: java/util/BitSet.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/util/BitSet.java,v
retrieving revision 1.18
diff -u -r1.18 BitSet.java
--- java/util/BitSet.java       2 Jul 2005 20:32:41 -0000       1.18
+++ java/util/BitSet.java       5 Jul 2005 10:14:24 -0000
@@ -116,8 +116,8 @@
    * given <code>set</code>.  This means it builds the intersection
    * of the two sets.  The result is stored into this bit set.
    *
-   * @param set the second bit set
-   * @throws NullPointerException if set is null
+   * @param bs the second bit set
+   * @throws NullPointerException if bs is null
    */
   public void and(BitSet bs)
   {
@@ -131,13 +131,13 @@
 
   /**
    * Performs the logical AND operation on this bit set and the
-   * complement of the given <code>set</code>.  This means it
+   * complement of the given <code>bs</code>.  This means it
    * selects every element in the first set, that isn't in the
    * second set.  The result is stored into this bit set and is
    * effectively the set difference of the two.
    *
-   * @param set the second bit set
-   * @throws NullPointerException if set is null
+   * @param bs the second bit set
+   * @throws NullPointerException if bs is null
    * @since 1.2
    */
   public void andNot(BitSet bs)
@@ -190,12 +190,12 @@
   }
 
   /**
-   * Removes the integer <code>bitIndex</code> from this set. That is
+   * Removes the integer <code>pos</code> from this set. That is
    * the corresponding bit is cleared.  If the index is not in the set,
    * this method does nothing.
    *
-   * @param bitIndex a non-negative integer
-   * @throws IndexOutOfBoundsException if bitIndex &lt; 0
+   * @param pos a non-negative integer
+   * @throws IndexOutOfBoundsException if pos &lt; 0
    */
   public void clear(int pos)
   {
@@ -336,8 +336,8 @@
    * set, otherwise false.
    *
    * @param pos a non-negative integer
-   * @return the value of the bit at the specified index
-   * @throws IndexOutOfBoundsException if the index is negative
+   * @return the value of the bit at the specified position
+   * @throws IndexOutOfBoundsException if the pos is negative
    */
   public boolean get(int pos)
   {
Index: java/util/Calendar.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/util/Calendar.java,v
retrieving revision 1.45
diff -u -r1.45 Calendar.java
--- java/util/Calendar.java     2 Jul 2005 20:32:41 -0000       1.45
+++ java/util/Calendar.java     5 Jul 2005 10:14:25 -0000
@@ -897,7 +897,6 @@
 
   /**
    * Fills any unset fields in the time field list
-   * @return true if the specified field has a value.
    */
   protected void complete()
   {
Index: java/util/Collections.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/util/Collections.java,v
retrieving revision 1.36
diff -u -r1.36 Collections.java
--- java/util/Collections.java  2 Jul 2005 20:32:41 -0000       1.36
+++ java/util/Collections.java  5 Jul 2005 10:14:32 -0000
@@ -298,7 +298,7 @@
      *
      * @param index The index of the element to retrieve.
      * @return the object at the specified index.
-     * @throws IndexOutofBoundsException as any given index
+     * @throws IndexOutOfBoundsException as any given index
      *         is outside the bounds of an empty array.
      */
     public Object get(int index)
@@ -2137,7 +2137,7 @@
      * within the underlying collection, first obtaining
      * a lock on the mutex.
      *
-     * @param cl the collection to test for.
+     * @param c1 the collection to test for.
      * @return <code>true</code> if for every element o in c, contains(o)
      *         would return <code>true</code>.
      * @throws ClassCastException if the type of any element in cl is not a 
valid
@@ -3396,7 +3396,7 @@
      * operation). If the map already contains a key, its value is replaced.
      * A lock is obtained on the mutex before the operation proceeds.
      *
-     * @param m the mapping to load into this map
+     * @param map the mapping to load into this map
      * @throws UnsupportedOperationException if the operation is not supported
      * @throws ClassCastException if a key or value is of the wrong type
      * @throws IllegalArgumentException if something about a key or value
@@ -3420,7 +3420,7 @@
      * <code>containsKey()</code> check is required to avoid this ambiguity.
      * Before the mapping is removed, a lock is obtained on the mutex.
      *
-     * @param key the key to remove
+     * @param o the key to remove
      * @return the value the key mapped to, or null if not present
      * @throws UnsupportedOperationException if deletion is unsupported
      * @throws NullPointerException if the key is null and this map doesn't
@@ -4109,7 +4109,7 @@
      * Test whether the underlying collection contains every element in a given
      * collection.
      *
-     * @param c the collection to test for.
+     * @param c1 the collection to test for.
      * @return <code>true</code> if for every element o in c, contains(o) would
      *         return <code>true</code>.
      * @throws ClassCastException if the type of any element in c is not a 
valid
Index: java/util/Hashtable.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/util/Hashtable.java,v
retrieving revision 1.34
diff -u -r1.34 Hashtable.java
--- java/util/Hashtable.java    2 Jul 2005 20:32:42 -0000       1.34
+++ java/util/Hashtable.java    5 Jul 2005 10:14:33 -0000
@@ -196,7 +196,7 @@
 
     /**
      * Resets the value.
-     * @param newValue the new value
+     * @param newVal the new value
      * @return the prior value
      * @throws NullPointerException if <code>newVal</code> is null
      */
Index: java/util/LinkedList.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/util/LinkedList.java,v
retrieving revision 1.25
diff -u -r1.25 LinkedList.java
--- java/util/LinkedList.java   2 Jul 2005 20:32:42 -0000       1.25
+++ java/util/LinkedList.java   5 Jul 2005 10:14:34 -0000
@@ -385,7 +385,7 @@
   /**
    * Adds an element to the end of the list.
    *
-   * @param e the entry to add
+   * @param o the entry to add
    * @return true, as it always succeeds
    */
   public boolean add(Object o)
Index: java/util/Properties.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/util/Properties.java,v
retrieving revision 1.28
diff -u -r1.28 Properties.java
--- java/util/Properties.java   2 Jul 2005 20:32:42 -0000       1.28
+++ java/util/Properties.java   5 Jul 2005 10:14:35 -0000
@@ -173,7 +173,7 @@
 # The safest way to include a space at the end of a value:
 label   = Name:\\u0020</pre>
    *
-   * @param in the input stream
+   * @param inStream the input stream
    * @throws IOException if an error occurred when reading the input
    * @throws NullPointerException if in is null
    */
Index: java/util/PropertyResourceBundle.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/util/PropertyResourceBundle.java,v
retrieving revision 1.15
diff -u -r1.15 PropertyResourceBundle.java
--- java/util/PropertyResourceBundle.java       2 Jul 2005 20:32:42 -0000       
1.15
+++ java/util/PropertyResourceBundle.java       5 Jul 2005 10:14:35 -0000
@@ -87,7 +87,7 @@
  * @author Jochen Hoenicke
  * @see ResourceBundle
  * @see ListResourceBundle
- * @see Properties#load()
+ * @see Properties#load(InputStream)
  * @since 1.1
  * @status updated to 1.4
  */
Index: java/util/ResourceBundle.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/util/ResourceBundle.java,v
retrieving revision 1.33
diff -u -r1.33 ResourceBundle.java
--- java/util/ResourceBundle.java       2 Jul 2005 20:32:42 -0000       1.33
+++ java/util/ResourceBundle.java       5 Jul 2005 10:14:37 -0000
@@ -359,7 +359,7 @@
    *
    * @param baseName the name of the ResourceBundle
    * @param locale A locale
-   * @param classloader a ClassLoader
+   * @param classLoader a ClassLoader
    * @return the desired resource bundle
    * @throws MissingResourceException if the resource bundle can't be found
    * @throws NullPointerException if any argument is null
Index: java/util/SimpleTimeZone.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/util/SimpleTimeZone.java,v
retrieving revision 1.26
diff -u -r1.26 SimpleTimeZone.java
--- java/util/SimpleTimeZone.java       2 Jul 2005 20:32:42 -0000       1.26
+++ java/util/SimpleTimeZone.java       5 Jul 2005 10:14:38 -0000
@@ -50,7 +50,7 @@
  * lying in the AD era.
  *
  * @see Calendar
- * @see GregorianCalender
+ * @see GregorianCalendar
  * @author Jochen Hoenicke
  */
 public class SimpleTimeZone extends TimeZone
@@ -126,7 +126,7 @@
 
   /**
    * This variable can have different meanings.  See startMode for details
-   * @see #startMode;
+   * @see #startMode
    * @serial
    */
   private int startDay;
@@ -135,7 +135,7 @@
    * This variable specifies the day of week the change takes place.  If
    * startMode == DOM_MODE, this is undefined.
    * @serial
-   * @see #startMode;
+   * @see #startMode
    */
   private int startDayOfWeek;
 
@@ -173,7 +173,7 @@
   /**
    * This variable can have different meanings.  See startMode for details
    * @serial
-   * @see #startMode;
+   * @see #startMode
    */
   private int endDay;
 
@@ -181,7 +181,7 @@
    * This variable specifies the day of week the change takes place.  If
    * endMode == DOM_MODE, this is undefined.
    * @serial
-   * @see #startMode;
+   * @see #startMode
    */
   private int endDayOfWeek;
 
@@ -309,13 +309,13 @@
    * @param id  The identifier of this time zone.
    * @param startMonth The start month of daylight savings; use the
    * constants in Calendar.
-   * @param startday A day in month or a day of week number, as
+   * @param startDayOfWeekInMonth A day in month or a day of week number, as
    * described above.
    * @param startDayOfWeek The start rule day of week; see above.
    * @param startTime A time in millis in standard time.
    * @param endMonth The end month of daylight savings; use the
    * constants in Calendar.
-   * @param endday A day in month or a day of week number, as
+   * @param endDayOfWeekInMonth A day in month or a day of week number, as
    * described above.
    * @param endDayOfWeek The end rule day of week; see above.
    * @param endTime A time in millis in standard time.
@@ -561,7 +561,7 @@
    * @param day A day in month, or a day of week in month.
    * @param dayOfWeek A day of week, when daylight savings ends.
    * @param time A time in millis in standard time.
-   * @see #setStartRule
+   * @see #setStartRule(int, int, int, int)
    */
   public void setEndRule(int month, int day, int dayOfWeek, int time)
   {
@@ -601,7 +601,7 @@
    * @param after If true, day and dayOfWeek specify first day of week on or
    * after day, else first day of week on or before.
    * @since 1.2
-   * @see #setStartRule
+   * @see #setStartRule(int, int, int, int, boolean)
    */
   public void setEndRule(int month, int day, int dayOfWeek, int time,
                          boolean after)
@@ -637,9 +637,8 @@
    *
    * @param month The end month of daylight savings.
    * @param day A day in month, or a day of week in month.
-   * @param dayOfWeek A day of week, when daylight savings ends.
    * @param time A time in millis in standard time.
-   * @see #setStartRule
+   * @see #setStartRule(int, int, int)
    */
   public void setEndRule(int month, int day, int time)
   {
Index: java/util/TreeMap.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/util/TreeMap.java,v
retrieving revision 1.27
diff -u -r1.27 TreeMap.java
--- java/util/TreeMap.java      2 Jul 2005 20:32:42 -0000       1.27
+++ java/util/TreeMap.java      5 Jul 2005 10:14:39 -0000
@@ -207,7 +207,7 @@
    * comparable by the Comparator, otherwise map operations may throw a
    * address@hidden ClassCastException}.
    *
-   * @param comparator the sort order for the keys of this map, or null
+   * @param c the sort order for the keys of this map, or null
    *        for the natural order
    */
   public TreeMap(Comparator c)

reply via email to

[Prev in Thread] Current Thread [Next in Thread]
Index: java/util/Date.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/util/Date.java,v
retrieving revision 1.22
diff -u -r1.22 Date.java
--- java/util/Date.java 2 Jul 2005 20:32:41 -0000       1.22
+++ java/util/Date.java 5 Jul 2005 10:14:33 -0000
@@ -41,6 +41,8 @@
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
 import java.io.Serializable;
+import java.text.DateFormat;
+import java.text.SimpleDateFormat;
 
 /**
  * <p>
@@ -240,8 +242,8 @@
    *             <code>TimeZone</code> instead.
    * @param year the difference between the required year and 1900.
    * @param month the month as a value between 0 and 11.
    * @param day the day as a value between 0 and 31.
    * @param hour the hour as a value between 0 and 23, in 24-hour
    *        clock notation.
    * @param min the minute as a value between 0 and 59.
    * @param sec the second as a value between 0 and 61 (with 60
@@ -718,7 +720,7 @@
    * </li>
    * </ul>
    *
-   * @param s The String to parse.
+   * @param string The String to parse.
    * @return The time in milliseconds since the epoch.
    * @throws IllegalArgumentException if the string fails to parse.
    * @deprecated Use DateFormat.parse(String)
@@ -240,8 +242,8 @@
    * @param year the difference between the required year and 1900.
    * @param month the month as a value between 0 and 11.
-   * @param day the day as a value between 0 and 31.
-   * @param hour the hour as a value between 0 and 23, in 24-hour
+   * @param date the day as a value between 0 and 31.
+   * @param hrs the hour as a value between 0 and 23, in 24-hour
    *        clock notation.
    * @param min the minute as a value between 0 and 59.